@@ -339,20 +339,20 @@ class DVPOAuth:
                         'AdditionalAddressInfo': data["AdditionalAddr"],
                         'Address': data['AddressLine1'],
                         'City': data["City"],
-                        'CompanyNumber': None,
+                        'CompanyNumber': '',
                         'State': data["State"],
                         'ZipCode': data["Zip"]
                     }
                 ]
             },
             'Header': {
-                'DateTimeStamp': datetime.fromtimestamp(eval(re.findall(r'\(.*?\)', resp_parent["ActiveTimeStamp"])[0])/1000), # ??? need parse the timestamp /Date(1672174552000)/
+                'DateTimeStamp': datetime.fromtimestamp(eval(re.findall(r'\(.*?\)', resp_parent["ActiveTimeStamp"])[0])/1000).strftime("%Y-%m-%d-%H.%M.%S.%f"), # ??? need parse the timestamp /Date(1672174552000)/
                 'MessageText': resp_parent["ReturnMessageText"],  # "Business Account details retrived successfully!"
                 'Result': resp_parent["InternetReturnCode"],
                 'ReturnCode': resp_parent["ErrorCode"] # Error code?
             },
             'MoreData': resp_parent["MoreData"],
-            'RowsReturned': resp_parent["RowsReturned"]
+            'RowsReturned': str(resp_parent["RowsReturned"])
         }
         return return_dict
     
